# This file was auto-generated by Fern from our API Definition.

from .types import (
    SessionsEventsResponse,
    SessionsEventsResponseError,
    SessionsEventsResponseStatus,
    SessionsEventsResponse_Error,
    SessionsEventsResponse_Status,
    SessionsListRequestStatus,
)

__all__ = [
    "SessionsEventsResponse",
    "SessionsEventsResponseError",
    "SessionsEventsResponseStatus",
    "SessionsEventsResponse_Error",
    "SessionsEventsResponse_Status",
    "SessionsListRequestStatus",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ExternalProfileV1(UniversalBaseModel):
    profile_id: typing_extensions.Annotated[str, FieldMetadata(alias="profileId")] = pydantic.Field()
    """
    Id of the profile.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Status of the profile.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



from .base_client import BaseClient, AsyncBaseClient
from .wrapper.windows_client import AirtopWindows, AsyncAirtopWindows
from .wrapper.sessions_client import AirtopSessions, AsyncAirtopSessions

class Airtop(BaseClient):
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : AirtopEnvironment
        The environment to use for requests from the client. from .environment import AirtopEnvironment



        Defaults to AirtopEnvironment.DEFAULT



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from airtop import Airtop

    client = Airtop(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(self, *, api_key: str, **kwargs):
        super().__init__(api_key=api_key, **kwargs)
        self.windows = AirtopWindows(client_wrapper=self._client_wrapper)
        self.sessions = AirtopSessions(client_wrapper=self._client_wrapper)



class AsyncAirtop(AsyncBaseClient):
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : AirtopEnvironment
        The environment to use for requests from the client. from .environment import AirtopEnvironment



        Defaults to AirtopEnvironment.DEFAULT



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from airtop import AsyncAirtop

    client = AsyncAirtop(
        api_key="YOUR_API_KEY",
    )
    """


    def __init__(self, *, api_key: str, **kwargs):
        super().__init__(api_key=api_key, **kwargs)
        self.windows = AsyncAirtopWindows(client_wrapper=self._client_wrapper)
        self.sessions = AsyncAirtopSessions(client_wrapper=self._client_wrapper)



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing_extensions
import datetime as dt
from ..core.serialization import FieldMetadata
from .status_message_status import StatusMessageStatus
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class StatusMessage(UniversalBaseModel):
    event: str = pydantic.Field()
    """
    Event name
    """

    event_time: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="eventTime")] = pydantic.Field()
    """
    Date and Time of the event
    """

    id: str = pydantic.Field()
    """
    ID of the session
    """

    status: StatusMessageStatus = pydantic.Field()
    """
    Status of the session
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



import time
import typing
from ..sessions.client import SessionsClient, AsyncSessionsClient
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.sessions_response import SessionsResponse
from ..core.pydantic_utilities import parse_obj_as
from ..errors.not_found_error import NotFoundError
from ..types.error_envelope import ErrorEnvelope
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..errors.internal_server_error import InternalServerError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.session_config_v1 import SessionConfigV1
from ..types.session_response import SessionResponse
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.jsonable_encoder import jsonable_encoder


# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)

RUNNINNG_STATUS = "running"

class ExtendedSessionConfigV1(SessionConfigV1):
    """
    Extended session configuration with additional properties.
    """
    skipWaitSessionReady: bool = False  # Default value

    def __init__(self, **kwargs):
        super().__init__(**kwargs)  # Ensure base class is initialized

# ... existing code ...
class AirtopSessions(SessionsClient):
    """
    AirtopSessions client functionality.
    """

    def create(
            self,
            *,
            configuration: typing.Optional[SessionConfigV1] = None, 
            request_options: typing.Optional[RequestOptions] = None,
        ) -> SessionResponse:
            extended_config = configuration if isinstance(configuration, ExtendedSessionConfigV1) else None
            
            session_config_v1 = SessionConfigV1(**{k: v for k, v in extended_config.__dict__.items() if k in SessionConfigV1.__fields__}) if extended_config else None
            session_data = super().create(configuration=session_config_v1, request_options=request_options)
            if extended_config is None or not extended_config.skipWaitSessionReady:
                self.wait_for_session_ready(session_data.data.id)
            return session_data

    def wait_for_session_ready(self, session_id: str, timeout_seconds: int = 60):
        initial_status = ""
        desired_status = RUNNINNG_STATUS
        status = initial_status
        start_time = time.time()

        while status != desired_status:
            status = self.getinfo(id=session_id).data.status
            if status == desired_status:
                break

            elapsed_time = time.time() - start_time
            if timeout_seconds and elapsed_time > timeout_seconds:
                break

            time.sleep(1)
        return status



class AsyncAirtopSessions(AsyncSessionsClient):
    """
    AsyncAirtopSessions client functionality.
    """

    async def create(
        self,
        *,
        configuration: typing.Optional[SessionConfigV1] = None, 
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SessionResponse:
        """
        Parameters
        ----------
        configuration : typing.Optional[SessionConfigV1]
            Session configuration

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SessionResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sessions.create()


        asyncio.run(main())
        """
        extended_config = configuration if isinstance(configuration, ExtendedSessionConfigV1) else None
        session_config_v1 = SessionConfigV1(**{k: v for k, v in extended_config.__dict__.items() if k in SessionConfigV1.__fields__}) if extended_config else None


        session_data = await super().create(configuration=session_config_v1, request_options=request_options)
        if extended_config is None or not extended_config.skipWaitSessionReady:
            await self.wait_for_session_ready(session_data.data.id)
        return session_data

    async def wait_for_session_ready(self, session_id: str, timeout_seconds: int = 60):
        initial_status = "UNINITIALIZED"
        desired_status = RUNNINNG_STATUS
        status = initial_status
        start_time = time.time()

        while status != desired_status:
            status = (await self.getinfo(id=session_id)).data.status
            if status == desired_status:
                break

            elapsed_time = time.time() - start_time
            if timeout_seconds and elapsed_time > timeout_seconds:
                break

            time.sleep(1)
        return status





# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class Pagination(UniversalBaseModel):
    current_limit: typing_extensions.Annotated[int, FieldMetadata(alias="currentLimit")]
    current_page: typing_extensions.Annotated[int, FieldMetadata(alias="currentPage")]
    final_count: typing_extensions.Annotated[int, FieldMetadata(alias="finalCount")]
    has_more: typing_extensions.Annotated[bool, FieldMetadata(alias="hasMore")]
    initial_count: typing_extensions.Annotated[int, FieldMetadata(alias="initialCount")]
    next_offset: typing_extensions.Annotated[int, FieldMetadata(alias="nextOffset")]
    number_of_pages: typing_extensions.Annotated[int, FieldMetadata(alias="numberOfPages")]
    total_items: typing_extensions.Annotated[int, FieldMetadata(alias="totalItems")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .sessions_events_response import (
    SessionsEventsResponse,
    SessionsEventsResponse_Error,
    SessionsEventsResponse_Status,
)
from .sessions_events_response_error import SessionsEventsResponseError
from .sessions_events_response_status import SessionsEventsResponseStatus
from .sessions_list_request_status import SessionsListRequestStatus

__all__ = [
    "SessionsEventsResponse",
    "SessionsEventsResponseError",
    "SessionsEventsResponseStatus",
    "SessionsEventsResponse_Error",
    "SessionsEventsResponse_Status",
    "SessionsListRequestStatus",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ScrapeResponseContent(UniversalBaseModel):
    content_type: typing_extensions.Annotated[str, FieldMetadata(alias="contentType")] = pydantic.Field()
    """
    The mime type of content extracted from the browser window (usually text/plain but could be text/csv or other types depending on the site).
    """

    text: str = pydantic.Field()
    """
    The text content of the browser window.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.create_window_input_v1body_wait_until import CreateWindowInputV1BodyWaitUntil
from ..core.request_options import RequestOptions
from ..types.window_id_response import WindowIdResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.window_response import WindowResponse
from .types.window_load_url_v1body_wait_until import WindowLoadUrlV1BodyWaitUntil
from ..types.empty_response import EmptyResponse
from ..types.prompt_content_config import PromptContentConfig
from ..types.ai_prompt_response import AiPromptResponse
from ..core.serialization import convert_and_respect_annotation_metadata
from ..types.scrape_response import ScrapeResponse
from ..types.summary_config import SummaryConfig
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WindowsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        session_id: str,
        *,
        screen_resolution: typing.Optional[str] = OMIT,
        url: typing.Optional[str] = OMIT,
        wait_until: typing.Optional[CreateWindowInputV1BodyWaitUntil] = OMIT,
        wait_until_timeout_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WindowIdResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        screen_resolution : typing.Optional[str]
            Affects the live view configuration. By default, a live view will fill the parent frame (or local window if loaded directly) when initially loaded, causing the browser window to be resized to match. This parameter can be used to instead configure the returned liveViewUrl so that the live view is loaded with fixed dimensions (e.g. 1280x720), resizing the browser window to match, and then disallows any further resizing from the live view.

        url : typing.Optional[str]
            Initial url to navigate to

        wait_until : typing.Optional[CreateWindowInputV1BodyWaitUntil]
            Wait until the specified loading event occurs. Defaults to 'load', which waits until the page dom and it's assets have loaded. 'domContentLoaded' will wait until the dom has loaded, and 'complete' will wait until the page and all it's iframes have loaded it's dom and assets.

        wait_until_timeout_seconds : typing.Optional[int]
            Maximum time in seconds to wait for the specified loading event to occur before timing out.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowIdResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.create(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows",
            method="POST",
            json={
                "screenResolution": screen_resolution,
                "url": url,
                "waitUntil": wait_until,
                "waitUntilTimeoutSeconds": wait_until_timeout_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowIdResponse,
                    parse_obj_as(
                        type_=WindowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_window_info(
        self,
        session_id: str,
        window_id: str,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WindowResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            ID of the browser window, which can either be a normal AirTop windowId or a [CDP TargetId](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetID) from a browser automation library like Puppeteer (typically associated with the page or main frame). Our SDKs will handle retrieving a TargetId for you from various popular browser automation libraries, but we also have details in our guides on how to do it manually.

        include_navigation_bar : typing.Optional[bool]
            Affects the live view configuration. A navigation bar is not shown in the live view of a browser by default. Set this to true to configure the returned liveViewUrl so that a navigation bar is rendered, allowing users to easily navigate the browser to other pages from the live view.

        disable_resize : typing.Optional[bool]
            Affects the live view configuration. Set to true to configure the returned liveViewUrl so that the ability to resize the browser window from the live view is disabled (resizing is allowed by default). Note that, at initial load, the live view will automatically fill the parent frame (or local window if loaded directly) and cause the browser window to be resized to match. This parameter does not affect that initial load behavior. See screenResolution for a way to set a fixed size for the live view.

        screen_resolution : typing.Optional[str]
            Affects the live view configuration. By default, a live view will fill the parent frame (or local window if loaded directly) when initially loaded, causing the browser window to be resized to match. This parameter can be used to instead configure the returned liveViewUrl so that the live view is loaded with fixed dimensions (e.g. 1280x720), resizing the browser window to match, and then disallows any further resizing from the live view.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.get_window_info(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
            screen_resolution="1280x720",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="GET",
            params={
                "includeNavigationBar": include_navigation_bar,
                "disableResize": disable_resize,
                "screenResolution": screen_resolution,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowResponse,
                    parse_obj_as(
                        type_=WindowResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def load_url(
        self,
        session_id: str,
        window_id: str,
        *,
        url: str,
        wait_until: typing.Optional[WindowLoadUrlV1BodyWaitUntil] = OMIT,
        wait_until_timeout_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            Airtop window ID of the browser window.

        url : str
            Url to navigate to

        wait_until : typing.Optional[WindowLoadUrlV1BodyWaitUntil]
            Wait until the specified loading event occurs. Defaults to 'load', which waits until the page dom and it's assets have loaded. 'domContentLoaded' will wait until the dom has loaded, and 'complete' will wait until the page and all it's iframes have loaded it's dom and assets.

        wait_until_timeout_seconds : typing.Optional[int]
            Maximum time in seconds to wait for the specified loading event to occur before timing out.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.load_url(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
            url="https://www.airtop.ai",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="POST",
            json={
                "url": url,
                "waitUntil": wait_until,
                "waitUntilTimeoutSeconds": wait_until_timeout_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EmptyResponse,
                    parse_obj_as(
                        type_=EmptyResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def close(
        self, session_id: str, window_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WindowIdResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            Airtop window ID of the browser window.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowIdResponse
            OK

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.close(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowIdResponse,
                    parse_obj_as(
                        type_=WindowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def prompt_content(
        self,
        session_id: str,
        window_id: str,
        *,
        prompt: str,
        client_request_id: typing.Optional[str] = OMIT,
        configuration: typing.Optional[PromptContentConfig] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        follow_pagination_links: typing.Optional[bool] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AiPromptResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to target with an Airtop AI prompt.

        prompt : str
            The prompt to submit about the content in the browser window.

        client_request_id : typing.Optional[str]

        configuration : typing.Optional[PromptContentConfig]
            Request configuration

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        follow_pagination_links : typing.Optional[bool]
            Make a best effort attempt to load more content items than are originally displayed on the page, e.g. by following pagination links, clicking controls to load more content, utilizing infinite scrolling, etc. This can be quite a bit more costly, but may be necessary for sites that require additional interaction to show the needed results. You can provide constraints in your prompt (e.g. on the total number of pages or results to consider).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AiPromptResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.prompt_content(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
            prompt="What is the main idea of this page?",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/prompt-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "configuration": convert_and_respect_annotation_metadata(
                    object_=configuration, annotation=PromptContentConfig, direction="write"
                ),
                "costThresholdCredits": cost_threshold_credits,
                "followPaginationLinks": follow_pagination_links,
                "prompt": prompt,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AiPromptResponse,
                    parse_obj_as(
                        type_=AiPromptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def scrape_content(
        self,
        session_id: str,
        window_id: str,
        *,
        client_request_id: typing.Optional[str] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ScrapeResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to scrape.

        client_request_id : typing.Optional[str]

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScrapeResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.scrape_content(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/scrape-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "costThresholdCredits": cost_threshold_credits,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScrapeResponse,
                    parse_obj_as(
                        type_=ScrapeResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def summarize_content(
        self,
        session_id: str,
        window_id: str,
        *,
        client_request_id: typing.Optional[str] = OMIT,
        configuration: typing.Optional[SummaryConfig] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AiPromptResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to summarize.

        client_request_id : typing.Optional[str]

        configuration : typing.Optional[SummaryConfig]
            Request configuration

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        prompt : typing.Optional[str]
            An optional prompt providing the Airtop AI model with additional direction or constraints about the summary (such as desired length).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AiPromptResponse
            Created

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.windows.summarize_content(
            session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/summarize-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "configuration": convert_and_respect_annotation_metadata(
                    object_=configuration, annotation=SummaryConfig, direction="write"
                ),
                "costThresholdCredits": cost_threshold_credits,
                "prompt": prompt,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AiPromptResponse,
                    parse_obj_as(
                        type_=AiPromptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncWindowsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        session_id: str,
        *,
        screen_resolution: typing.Optional[str] = OMIT,
        url: typing.Optional[str] = OMIT,
        wait_until: typing.Optional[CreateWindowInputV1BodyWaitUntil] = OMIT,
        wait_until_timeout_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WindowIdResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        screen_resolution : typing.Optional[str]
            Affects the live view configuration. By default, a live view will fill the parent frame (or local window if loaded directly) when initially loaded, causing the browser window to be resized to match. This parameter can be used to instead configure the returned liveViewUrl so that the live view is loaded with fixed dimensions (e.g. 1280x720), resizing the browser window to match, and then disallows any further resizing from the live view.

        url : typing.Optional[str]
            Initial url to navigate to

        wait_until : typing.Optional[CreateWindowInputV1BodyWaitUntil]
            Wait until the specified loading event occurs. Defaults to 'load', which waits until the page dom and it's assets have loaded. 'domContentLoaded' will wait until the dom has loaded, and 'complete' will wait until the page and all it's iframes have loaded it's dom and assets.

        wait_until_timeout_seconds : typing.Optional[int]
            Maximum time in seconds to wait for the specified loading event to occur before timing out.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowIdResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.create(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows",
            method="POST",
            json={
                "screenResolution": screen_resolution,
                "url": url,
                "waitUntil": wait_until,
                "waitUntilTimeoutSeconds": wait_until_timeout_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowIdResponse,
                    parse_obj_as(
                        type_=WindowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_window_info(
        self,
        session_id: str,
        window_id: str,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WindowResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            ID of the browser window, which can either be a normal AirTop windowId or a [CDP TargetId](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetID) from a browser automation library like Puppeteer (typically associated with the page or main frame). Our SDKs will handle retrieving a TargetId for you from various popular browser automation libraries, but we also have details in our guides on how to do it manually.

        include_navigation_bar : typing.Optional[bool]
            Affects the live view configuration. A navigation bar is not shown in the live view of a browser by default. Set this to true to configure the returned liveViewUrl so that a navigation bar is rendered, allowing users to easily navigate the browser to other pages from the live view.

        disable_resize : typing.Optional[bool]
            Affects the live view configuration. Set to true to configure the returned liveViewUrl so that the ability to resize the browser window from the live view is disabled (resizing is allowed by default). Note that, at initial load, the live view will automatically fill the parent frame (or local window if loaded directly) and cause the browser window to be resized to match. This parameter does not affect that initial load behavior. See screenResolution for a way to set a fixed size for the live view.

        screen_resolution : typing.Optional[str]
            Affects the live view configuration. By default, a live view will fill the parent frame (or local window if loaded directly) when initially loaded, causing the browser window to be resized to match. This parameter can be used to instead configure the returned liveViewUrl so that the live view is loaded with fixed dimensions (e.g. 1280x720), resizing the browser window to match, and then disallows any further resizing from the live view.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.get_window_info(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
                screen_resolution="1280x720",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="GET",
            params={
                "includeNavigationBar": include_navigation_bar,
                "disableResize": disable_resize,
                "screenResolution": screen_resolution,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowResponse,
                    parse_obj_as(
                        type_=WindowResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def load_url(
        self,
        session_id: str,
        window_id: str,
        *,
        url: str,
        wait_until: typing.Optional[WindowLoadUrlV1BodyWaitUntil] = OMIT,
        wait_until_timeout_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            Airtop window ID of the browser window.

        url : str
            Url to navigate to

        wait_until : typing.Optional[WindowLoadUrlV1BodyWaitUntil]
            Wait until the specified loading event occurs. Defaults to 'load', which waits until the page dom and it's assets have loaded. 'domContentLoaded' will wait until the dom has loaded, and 'complete' will wait until the page and all it's iframes have loaded it's dom and assets.

        wait_until_timeout_seconds : typing.Optional[int]
            Maximum time in seconds to wait for the specified loading event to occur before timing out.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.load_url(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
                url="https://www.airtop.ai",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="POST",
            json={
                "url": url,
                "waitUntil": wait_until,
                "waitUntilTimeoutSeconds": wait_until_timeout_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EmptyResponse,
                    parse_obj_as(
                        type_=EmptyResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def close(
        self, session_id: str, window_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WindowIdResponse:
        """
        Parameters
        ----------
        session_id : str
            ID of the session that owns the window.

        window_id : str
            Airtop window ID of the browser window.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WindowIdResponse
            OK

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.close(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="7334da2a-91b0-42c5-6156-76a5eba87430",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    WindowIdResponse,
                    parse_obj_as(
                        type_=WindowIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def prompt_content(
        self,
        session_id: str,
        window_id: str,
        *,
        prompt: str,
        client_request_id: typing.Optional[str] = OMIT,
        configuration: typing.Optional[PromptContentConfig] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        follow_pagination_links: typing.Optional[bool] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AiPromptResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to target with an Airtop AI prompt.

        prompt : str
            The prompt to submit about the content in the browser window.

        client_request_id : typing.Optional[str]

        configuration : typing.Optional[PromptContentConfig]
            Request configuration

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        follow_pagination_links : typing.Optional[bool]
            Make a best effort attempt to load more content items than are originally displayed on the page, e.g. by following pagination links, clicking controls to load more content, utilizing infinite scrolling, etc. This can be quite a bit more costly, but may be necessary for sites that require additional interaction to show the needed results. You can provide constraints in your prompt (e.g. on the total number of pages or results to consider).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AiPromptResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.prompt_content(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
                prompt="What is the main idea of this page?",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/prompt-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "configuration": convert_and_respect_annotation_metadata(
                    object_=configuration, annotation=PromptContentConfig, direction="write"
                ),
                "costThresholdCredits": cost_threshold_credits,
                "followPaginationLinks": follow_pagination_links,
                "prompt": prompt,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AiPromptResponse,
                    parse_obj_as(
                        type_=AiPromptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def scrape_content(
        self,
        session_id: str,
        window_id: str,
        *,
        client_request_id: typing.Optional[str] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ScrapeResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to scrape.

        client_request_id : typing.Optional[str]

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScrapeResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.scrape_content(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/scrape-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "costThresholdCredits": cost_threshold_credits,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScrapeResponse,
                    parse_obj_as(
                        type_=ScrapeResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def summarize_content(
        self,
        session_id: str,
        window_id: str,
        *,
        client_request_id: typing.Optional[str] = OMIT,
        configuration: typing.Optional[SummaryConfig] = OMIT,
        cost_threshold_credits: typing.Optional[int] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        time_threshold_seconds: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AiPromptResponse:
        """
        Parameters
        ----------
        session_id : str
            The session id for the window.

        window_id : str
            The Airtop window id of the browser window to summarize.

        client_request_id : typing.Optional[str]

        configuration : typing.Optional[SummaryConfig]
            Request configuration

        cost_threshold_credits : typing.Optional[int]
            A credit threshold that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

        prompt : typing.Optional[str]
            An optional prompt providing the Airtop AI model with additional direction or constraints about the summary (such as desired length).

        time_threshold_seconds : typing.Optional[int]
            A time threshold in seconds that, once exceeded, will cause the operation to be cancelled. Note that this is *not* a hard limit, but a threshold that is checked periodically during the course of fulfilling the request. A default threshold is used if not specified, but you can use this option to increase or decrease as needed. Set to 0 to disable this feature entirely (not recommended).

            This setting does not extend the maximum session duration provided at the time of session creation.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AiPromptResponse
            Created

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.windows.summarize_content(
                session_id="6aac6f73-bd89-4a76-ab32-5a6c422e8b0b",
                window_id="0334da2a-91b0-42c5-6156-76a5eba87430",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sessions/{jsonable_encoder(session_id)}/windows/{jsonable_encoder(window_id)}/summarize-content",
            method="POST",
            json={
                "clientRequestId": client_request_id,
                "configuration": convert_and_respect_annotation_metadata(
                    object_=configuration, annotation=SummaryConfig, direction="write"
                ),
                "costThresholdCredits": cost_threshold_credits,
                "prompt": prompt,
                "timeThresholdSeconds": time_threshold_seconds,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AiPromptResponse,
                    parse_obj_as(
                        type_=AiPromptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ..core.serialization import FieldMetadata
import pydantic
from .external_session_config import ExternalSessionConfig
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ExternalSessionWithConnectionInfo(UniversalBaseModel):
    cdp_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="cdpUrl")] = pydantic.Field(
        default=None
    )
    """
    Url to connect to chrome devtools protocol port on the Airtop browser. Include the header 'Authorization: Bearer <api-key>.'
    """

    cdp_ws_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="cdpWsUrl")] = pydantic.Field(
        default=None
    )
    """
    Websocket url to connect to the Airtop browser for CDP-based automation frameworks (e.g. Puppeteer or Playwright). Include the header 'Authorization: Bearer <airtop-api-key>.'
    """

    chromedriver_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="chromedriverUrl")] = (
        pydantic.Field(default=None)
    )
    """
    Websocket url to connect to the Airtop browser for webdriver-based automation frameworks (e.g. Selenium). Include the header 'Authorization: Bearer <airtop-api-key>.'
    """

    configuration: ExternalSessionConfig = pydantic.Field()
    """
    Session configuration details.
    """

    current_usage: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="currentUsage")] = (
        pydantic.Field(default=None)
    )
    """
    Current usage in minutes.
    """

    date_created: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="dateCreated")] = (
        pydantic.Field(default=None)
    )
    """
    Date the session was created.
    """

    id: str = pydantic.Field()
    """
    Id of the session.
    """

    last_activity: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="lastActivity")] = (
        pydantic.Field(default=None)
    )
    """
    Date of the last activity.
    """

    profile_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="profileId")] = pydantic.Field(
        default=None
    )
    """
    Id of a newly persisted profile.
    """

    status: str = pydantic.Field()
    """
    Session status.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



import typing
import requests
from ..windows.client import WindowsClient, AsyncWindowsClient
from ..core.request_options import RequestOptions
from ..types import ExternalSessionWithConnectionInfo

# ... existing code ...
class AirtopWindows(WindowsClient):
    """
    AirtopWindows client that extends the WindowsClient functionality.
    """

    def _get_playwright_target_id(self, playwright_page):
        cdp_session = playwright_page.context.new_cdp_session(playwright_page)
        target_info = cdp_session.send("Target.getTargetInfo")
        return target_info["targetInfo"]["targetId"]

    def _get_selenium_target_id(self, selenium_driver, session: ExternalSessionWithConnectionInfo):
        airtop_api_key = self._client_wrapper._api_key
        chromedriver_session_url = f"{session.chromedriver_url}/session/{selenium_driver.session_id}/chromium/send_command_and_get_result"
        response = requests.post(
            chromedriver_session_url,
            headers={
                'Content-Type': 'application/json',
                'Authorization': f'Bearer {airtop_api_key}'
            },
            json={
                'cmd': 'Target.getTargetInfo',
                'params': {}
            }
        )
        return response.json().get('value', {}).get('targetInfo', {}).get('targetId', None)

    def get_window_info_for_playwright_page(
        self,
        session: ExternalSessionWithConnectionInfo,
        playwright_page,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ):
        target_id = self._get_playwright_target_id(playwright_page)
        return self.get_window_info(
            session_id=session.id,
            window_id=target_id,
            include_navigation_bar=include_navigation_bar,
            disable_resize=disable_resize,
            screen_resolution=screen_resolution,
            request_options=request_options
        )

    def get_window_info_for_selenium_driver(
        self,
        session: ExternalSessionWithConnectionInfo,
        selenium_driver,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ):
        target_id = self._get_selenium_target_id(selenium_driver, session)
        return self.get_window_info(
            session_id=session.id,
            window_id=target_id,
            include_navigation_bar=include_navigation_bar,
            disable_resize=disable_resize,
            screen_resolution=screen_resolution,
            request_options=request_options
        )





class AsyncAirtopWindows(AsyncWindowsClient):
    """
    AsyncAirtopWindows client that extends the AsyncWindowsClient functionality.
    """

    async def _get_playwright_target_id(self, playwright_page):
        cdp_session = await playwright_page.context.new_cdp_session(playwright_page)
        target_info = await cdp_session.send("Target.getTargetInfo")
        return target_info["targetInfo"]["targetId"]

    async def _get_selenium_target_id(self, selenium_driver, session: ExternalSessionWithConnectionInfo):
        airtop_api_key = self._client_wrapper._api_key
        chromedriver_session_url = f"{session.chromedriver_url}/session/{selenium_driver.session_id}/chromium/send_command_and_get_result"
        response = requests.post(
            chromedriver_session_url,
            headers={
                'Content-Type': 'application/json',
                'Authorization': f'Bearer {airtop_api_key}'
            },
            json={
                'cmd': 'Target.getTargetInfo',
                'params': {}
            }
        )
        return response.json().get('value', {}).get('targetInfo', {}).get('targetId', None)

    async def get_window_info_for_playwright_page(
        self,
        session: ExternalSessionWithConnectionInfo,
        playwright_page,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ):
        target_id = await self._get_playwright_target_id(playwright_page)
        return await self.get_window_info(
            session_id=session.id,
            window_id=target_id,
            include_navigation_bar=include_navigation_bar,
            disable_resize=disable_resize,
            screen_resolution=screen_resolution,
            request_options=request_options
        )

    async def get_window_info_for_selenium_driver(
        self,
        session: ExternalSessionWithConnectionInfo,
        selenium_driver,
        *,
        include_navigation_bar: typing.Optional[bool] = None,
        disable_resize: typing.Optional[bool] = None,
        screen_resolution: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ):
        target_id = await self._get_selenium_target_id(selenium_driver, session)
        return await self.get_window_info(
            session_id=session.id,
            window_id=target_id,
            include_navigation_bar=include_navigation_bar,
            disable_resize=disable_resize,
            screen_resolution=screen_resolution,
            request_options=request_options
        )



# This file was auto-generated by Fern from our API Definition.

from .create_window_input_v1body_wait_until import CreateWindowInputV1BodyWaitUntil
from .window_load_url_v1body_wait_until import WindowLoadUrlV1BodyWaitUntil

__all__ = ["CreateWindowInputV1BodyWaitUntil", "WindowLoadUrlV1BodyWaitUntil"]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ..core.serialization import FieldMetadata
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SessionConfigV1(UniversalBaseModel):
    base_profile_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseProfileId")] = (
        pydantic.Field(default=None)
    )
    """
    Id of a profile to load into the session.
    """

    persist_profile: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="persistProfile")] = (
        pydantic.Field(default=None)
    )
    """
    Persist the profile.
    """

    timeout_minutes: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="timeoutMinutes")] = (
        pydantic.Field(default=None)
    )
    """
    Max length of session in minutes, after which it will terminate if not already deleted.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AiPromptResponse,
    AiResponseEnvelope,
    ClientProvidedResponseMetadata,
    EmptyResponse,
    EmptyResponseJson,
    EnvelopeDefaultMeta,
    EnvelopeStatusDefaultMeta,
    EnvelopeStatusDefaultMetaStatus,
    ErrorEnvelope,
    ErrorMessage,
    ExternalProfileV1,
    ExternalSessionAiResponseMetadata,
    ExternalSessionAiResponseMetadataStatus,
    ExternalSessionAiResponseMetadataUsage,
    ExternalSessionConfig,
    ExternalSessionWithConnectionInfo,
    Issue,
    Pagination,
    ProfilesResponse,
    PromptContentConfig,
    PromptContentExperimentalConfig,
    ScrapeResponse,
    ScrapeResponseContent,
    ScrapeResponseEnvelope,
    ScrapeResponseOutput,
    SessionConfigV1,
    SessionResponse,
    SessionsResponse,
    SessionsWithPagination,
    StatusMessage,
    StatusMessageStatus,
    SummaryConfig,
    SummaryExperimentalConfig,
    Window,
    WindowId,
    WindowIdResponse,
    WindowResponse,
)
from .errors import InternalServerError, NotFoundError, UnprocessableEntityError
from . import profiles, sessions, windows
from .client import Airtop, AsyncAirtop
from .environment import AirtopEnvironment
from .sessions import (
    SessionsEventsResponse,
    SessionsEventsResponseError,
    SessionsEventsResponseStatus,
    SessionsEventsResponse_Error,
    SessionsEventsResponse_Status,
    SessionsListRequestStatus,
)
from .version import __version__
from .windows import CreateWindowInputV1BodyWaitUntil, WindowLoadUrlV1BodyWaitUntil

__all__ = [
    "AiPromptResponse",
    "AiResponseEnvelope",
    "Airtop",
    "AirtopEnvironment",
    "AsyncAirtop",
    "ClientProvidedResponseMetadata",
    "CreateWindowInputV1BodyWaitUntil",
    "EmptyResponse",
    "EmptyResponseJson",
    "EnvelopeDefaultMeta",
    "EnvelopeStatusDefaultMeta",
    "EnvelopeStatusDefaultMetaStatus",
    "ErrorEnvelope",
    "ErrorMessage",
    "ExternalProfileV1",
    "ExternalSessionAiResponseMetadata",
    "ExternalSessionAiResponseMetadataStatus",
    "ExternalSessionAiResponseMetadataUsage",
    "ExternalSessionConfig",
    "ExternalSessionWithConnectionInfo",
    "InternalServerError",
    "Issue",
    "NotFoundError",
    "Pagination",
    "ProfilesResponse",
    "PromptContentConfig",
    "PromptContentExperimentalConfig",
    "ScrapeResponse",
    "ScrapeResponseContent",
    "ScrapeResponseEnvelope",
    "ScrapeResponseOutput",
    "SessionConfigV1",
    "SessionResponse",
    "SessionsEventsResponse",
    "SessionsEventsResponseError",
    "SessionsEventsResponseStatus",
    "SessionsEventsResponse_Error",
    "SessionsEventsResponse_Status",
    "SessionsListRequestStatus",
    "SessionsResponse",
    "SessionsWithPagination",
    "StatusMessage",
    "StatusMessageStatus",
    "SummaryConfig",
    "SummaryExperimentalConfig",
    "UnprocessableEntityError",
    "Window",
    "WindowId",
    "WindowIdResponse",
    "WindowLoadUrlV1BodyWaitUntil",
    "WindowResponse",
    "__version__",
    "profiles",
    "sessions",
    "windows",
]



# This file was auto-generated by Fern from our API Definition.

from .ai_prompt_response import AiPromptResponse
from .ai_response_envelope import AiResponseEnvelope
from .client_provided_response_metadata import ClientProvidedResponseMetadata
from .empty_response import EmptyResponse
from .empty_response_json import EmptyResponseJson
from .envelope_default_meta import EnvelopeDefaultMeta
from .envelope_status_default_meta import EnvelopeStatusDefaultMeta
from .envelope_status_default_meta_status import EnvelopeStatusDefaultMetaStatus
from .error_envelope import ErrorEnvelope
from .error_message import ErrorMessage
from .external_profile_v1 import ExternalProfileV1
from .external_session_ai_response_metadata import ExternalSessionAiResponseMetadata
from .external_session_ai_response_metadata_status import ExternalSessionAiResponseMetadataStatus
from .external_session_ai_response_metadata_usage import ExternalSessionAiResponseMetadataUsage
from .external_session_config import ExternalSessionConfig
from .external_session_with_connection_info import ExternalSessionWithConnectionInfo
from .issue import Issue
from .pagination import Pagination
from .profiles_response import ProfilesResponse
from .prompt_content_config import PromptContentConfig
from .prompt_content_experimental_config import PromptContentExperimentalConfig
from .scrape_response import ScrapeResponse
from .scrape_response_content import ScrapeResponseContent
from .scrape_response_envelope import ScrapeResponseEnvelope
from .scrape_response_output import ScrapeResponseOutput
from .session_config_v1 import SessionConfigV1
from .session_response import SessionResponse
from .sessions_response import SessionsResponse
from .sessions_with_pagination import SessionsWithPagination
from .status_message import StatusMessage
from .status_message_status import StatusMessageStatus
from .summary_config import SummaryConfig
from .summary_experimental_config import SummaryExperimentalConfig
from .window import Window
from .window_id import WindowId
from .window_id_response import WindowIdResponse
from .window_response import WindowResponse

__all__ = [
    "AiPromptResponse",
    "AiResponseEnvelope",
    "ClientProvidedResponseMetadata",
    "EmptyResponse",
    "EmptyResponseJson",
    "EnvelopeDefaultMeta",
    "EnvelopeStatusDefaultMeta",
    "EnvelopeStatusDefaultMetaStatus",
    "ErrorEnvelope",
    "ErrorMessage",
    "ExternalProfileV1",
    "ExternalSessionAiResponseMetadata",
    "ExternalSessionAiResponseMetadataStatus",
    "ExternalSessionAiResponseMetadataUsage",
    "ExternalSessionConfig",
    "ExternalSessionWithConnectionInfo",
    "Issue",
    "Pagination",
    "ProfilesResponse",
    "PromptContentConfig",
    "PromptContentExperimentalConfig",
    "ScrapeResponse",
    "ScrapeResponseContent",
    "ScrapeResponseEnvelope",
    "ScrapeResponseOutput",
    "SessionConfigV1",
    "SessionResponse",
    "SessionsResponse",
    "SessionsWithPagination",
    "StatusMessage",
    "StatusMessageStatus",
    "SummaryConfig",
    "SummaryExperimentalConfig",
    "Window",
    "WindowId",
    "WindowIdResponse",
    "WindowResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .pagination import Pagination
import pydantic
import typing
from .external_session_with_connection_info import ExternalSessionWithConnectionInfo
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SessionsWithPagination(UniversalBaseModel):
    pagination: Pagination = pydantic.Field()
    """
    Pagination details.
    """

    sessions: typing.Optional[typing.List[ExternalSessionWithConnectionInfo]] = pydantic.Field(default=None)
    """
    List of sessions.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class Window(UniversalBaseModel):
    live_view_url: typing_extensions.Annotated[str, FieldMetadata(alias="liveViewUrl")] = pydantic.Field()
    """
    Url for loading a browser window live view that is configured according to the request options like screenResolution, disableResize, etc.
    """

    window_id: typing_extensions.Annotated[str, FieldMetadata(alias="windowId")] = pydantic.Field()
    """
    Airtop window ID of the browser window
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import typing
from .issue import Issue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ErrorEnvelope(UniversalBaseModel):
    http_status: typing_extensions.Annotated[int, FieldMetadata(alias="HttpStatus")]
    message: typing_extensions.Annotated[str, FieldMetadata(alias="Message")]
    data: typing.Optional[typing.Any] = None
    errors: typing.Optional[typing.List[Issue]] = None
    meta: typing.Optional[typing.Any] = None
    warnings: typing.Optional[typing.List[Issue]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
